@@ -108,9 +108,6 @@ animate_process <- function(eventlog,
     stop("The 'initial_time' parameter should be less or equal than the specified 'duration'.")
   }
 
-  start_activity <- processmap$nodes_df %>% filter(label == "Start") %>% pull(id)
-  end_activity <- processmap$nodes_df %>% filter(label == "End") %>% pull(id)
-
   precedence <- NULL
   if (!is.null(attr(processmap, "base_precedence"))) {
     precedence <- attr(processmap, "base_precedence") %>%
@@ -130,6 +127,9 @@ animate_process <- function(eventlog,
     stop("Missing attribute `base_precedence` or `causal_nodes`. Did you supply a process map generated by `process_map` or `render_causal_net`? ")
   }
 
+  start_activity <- processmap$nodes_df %>% filter(label == "Start") %>% pull(id)
+  end_activity <- processmap$nodes_df %>% filter(label == "End") %>% pull(id)
+
   if (mode != "off" && !is.null(precedence)) {
 
     suppressWarnings({
@@ -208,12 +208,6 @@ animate_process <- function(eventlog,
   # actually render the process map
   rendered_process <- renderer(processmap, width, height)
 
-  # hack to add 'weight' attribute to the graph
-  rendered_process %>%
-    stringr::str_replace_all("len", "weight") %>%
-    stringr::str_replace_all("decorate", "constraint") -> rendered_process
-
-  settings <- list()
   x <- list(
     rendered_process = rendered_process,
     activities = activities,
@@ -249,12 +243,15 @@ animate_process <- function(eventlog,
     processmap_renderer = attr(renderer, "name")
   )
 
+  x <- c(x, attr(renderer, "config"))
+
   htmlwidgets::createWidget(elementId = elementId,
                             name = "processanimateR",
                             x = x,
                             width = width, height = height,
                             sizingPolicy = sizingPolicy,
-                            preRenderHook = preRenderHook)
+                            preRenderHook = preRenderHook,
+                            dependencies = attr(renderer, "dependencies"))
 }
 
 #' @title Create a process animation output element
